Learn R Programming

popbayes (version 1.2.0)

w_to_rmax: Compute rmax from adult female body mass

Description

The demographic potential of a species is limited. The intrinsic rate of increase rmax is the maximum increase in log population size that a species can attain in a year. According to Sinclair (2003), it is related to the body mass of adult females by: \(1.375 \times W^{-0.315}\)

Usage

w_to_rmax(w)

Value

A numerical vector of rmax values.

Arguments

w

a numerical vector. Adult female body mass (in kg).

References

Sinclair (2013) Mammal population regulation, keystone processes and ecosystem dynamics. Philosophical Transactions: Biological Sciences, 358, 1729-1740.

Examples

Run this code
## Set adult female body mass ----
body_masses <- c(55, 127)

## Add species names ----
names(body_masses) <- c("Impala", "Tiang")

## Compute species rmax ----
w_to_rmax(body_masses)

Run the code above in your browser using DataLab