This dataset contains individual counts of 10 African mammal species in the Garamba National Park (Democratic Republic of the Congo) from 1976 to 2017.
garambaA data.frame with 141 rows (counts) and the following 8 variables:
the location of the survey (Garamba)
the binomial name of the species
the date of the survey
the method used to estimate individuals counts. One of
T (total counts), G (guesstimate), and S
(sampling counts)
the field method used to collect data. One of
A (aerial counts), and G (ground counts)
number of individuals
lower boundary of the 95% confidence interval of the counts (only for sampling counts)
upper boundary of the 95% confidence interval of the counts (only for sampling counts)
the preferred field method of the species. One of
A for Aerial counts, and G for Ground counts
the conversion multiplicative factor (corresponding to the detectability category) used to convert aerial to ground counts
the maximum population growth rate
Hillman Smith K & Kalpers J (2015) Garamba Conservation in Peace & War.
Hillman Smith publisher, 448pp. ISBN: 9789966185105.
Monico M (2014)
Aerial Survey Report March 2014 - Garamba National Park, DRC.
African Parks Network/ICCN/Pan-African Elephant Aerial Survey, 42pp.
Spies K et al. (2017)
Aerial Survey Report April 2017 - Garamba National Park, DRC.
African Parks Network/EU/ICCN. 38pp.
data("garamba")
head(garamba, 30)
Run the code above in your browser using DataLab